@@ -1,8 +1,17 @@
-## ----setup, include=FALSE------------------------------------------------
+## ---- include = FALSE----------------------------------------------------
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>"
+)
+
+library(dplyr)
+library(tidypredict)
+library(parsnip)
+
+## ------------------------------------------------------------------------
 library(dplyr)
 library(tidypredict)
 
-## ------------------------------------------------------------------------
 df <- mtcars %>%
   mutate(char_cyl = paste0("cyl", cyl)) %>%
   select(mpg, wt, char_cyl, am) 
@@ -11,7 +20,6 @@ model <- lm(mpg ~ wt + char_cyl, offset = am, data = df)
 
 ## ------------------------------------------------------------------------
 library(tidypredict)
-
 tidypredict_sql(model, dbplyr::simulate_mssql())
 
 ## ------------------------------------------------------------------------
@@ -28,7 +36,8 @@ df %>%
   head(10)
 
 ## ------------------------------------------------------------------------
-parse_model(model)
+pm <- parse_model(model)
+str(pm, 2)
 
 ## ------------------------------------------------------------------------
 tidypredict_fit(model)
@@ -42,3 +51,12 @@ tidypredict_test(model)
 ## ------------------------------------------------------------------------
 tidypredict_test(model, include_intervals = TRUE)
 
+## ------------------------------------------------------------------------
+library(parsnip)
+
+parsnip_model <- linear_reg() %>%
+  set_engine("lm") %>%
+  fit(mpg ~ wt + cyl, offset = am, data = mtcars)
+
+tidypredict_fit(parsnip_model)
+
